package it.unitn.disi.ronchet.giocoacarte;

import java.util.HashSet;

/** La mano è l'insieme di carte che in un dato istante il giocatore ha in mano.
 *
 * @author ronchet
 */
public class Mano extends HashSet<CartaDaGioco>{
    final int CARTE_IN_UNA_MANO=5;
    /** Inizialmente una mano viene composta prelevando dal mazzo un numero sufficiente di carte
     * 
     * @param mazzo il mazzo da cui vengono pescate le carte
     */
    Mano(Mazzo mazzo){        
        for (int k=0;k<CARTE_IN_UNA_MANO;k++) {
           CartaDaGioco carta=addCarta(mazzo);
           System.out.print(carta);
        }
        System.out.println();
    }
    /** Controlla se si è tentato di aggiungere alla mano elementi duplicati.
     * Questa implementazione, che potrebbe essere sostituita con un'altra,
     * si basa sul fatto che in un set  gli elementi duplicati non vengono inseriti, 
     * quindi se ve ne erano il conteggio degli elementi della mano risulta
     * minore di quanto atteso.
     * 
     * @return vero se vi sono elementi duplicati 
     */
    boolean haDuplicati(){
        return this.size()<CARTE_IN_UNA_MANO;
    }
    /**
     * Aggiunge una carta alla mano pescandola dal mazzo
     * @param mazzo il mazzo da cui si preleva
     * @return la carta pescata
     */
    CartaDaGioco addCarta(Mazzo mazzo) {
        CartaDaGioco carta=mazzo.getCarta();
        boolean unica=add(carta);
        if (!unica) System.out.print("Carta doppia: ");
        return carta;
    }
    /** scarta una carta
     * @return la carta scartata
     */
    CartaDaGioco removeCarta() {
        // Nota: i set non hanno il metodo get, dobbiamo sostituirlo usando un itarator
        CartaDaGioco carta=this.iterator().next();
        remove(carta);
        return carta;
    }

    @Override
    public String toString() {
        String retval="";
        for (CartaDaGioco c : this) {retval=retval+c;}
        return retval;
    }
    
    
}
